@@ -36,10 +36,6 @@ class Enviar(object):
     def valor_envio(self):
         return self.pedido.valor_total - self.pedido.valor_subtotal + self.pedido.valor_desconto
 
-    @property
-    def valor_desconto(self):
-        return self.pedido.valor_desconto
-
 
 class EnviarPedido(Plugavel):
     def __init__(self, pedido_numero, dados, conta_id, configuracao_pagamento):
