@@ -103,3 +103,13 @@ class Formatador(object):
             return resultado
         root = ElementTree.fromstring(content)
         return iterando(root)
+
+    @classmethod
+    def trata_unicode_com_limite(cls, texto, limite=None):
+        if not texto:
+            return ""
+        if type(texto) in [unicode, str]:
+            texto = texto.encode("utf-8")
+        if limite:
+            return texto[:limite]
+        return texto
